@@ -1,38 +1,43 @@
-/*
- * -----------------------------------------------------------------
- * $Revision: 4272 $
- * $Date: 2014-12-02 11:19:41 -0800 (Tue, 02 Dec 2014) $
- * -----------------------------------------------------------------
+/* -----------------------------------------------------------------
  * Programmer: Radu Serban and Cosmin Petra @ LLNL
  * -----------------------------------------------------------------
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * and Southern Methodist University.
+ * All rights reserved.
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
+ * -----------------------------------------------------------------
  * Simulation of a slider-crank mechanism modelled with 3 generalized
  * coordinates: crank angle, connecting bar angle, and slider location.
- * The mechanism moves under the action of a constant horizontal 
- * force applied to the connecting rod and a spring-damper connecting 
+ * The mechanism moves under the action of a constant horizontal
+ * force applied to the connecting rod and a spring-damper connecting
  * the crank and connecting rod.
  *
  * The equations of motion are formulated as a system of stabilized
  * index-2 DAEs (Gear-Gupta-Leimkuhler formulation).
  *
- * IDAS also computes sensitivities with respect to the problem 
- * parameters k (spring constant) and c (damper constant) of the 
+ * IDAS also computes sensitivities with respect to the problem
+ * parameters k (spring constant) and c (damper constant) of the
  * kinetic energy:
- *   G = int_t0^tend g(t,y,p) dt, 
+ *   G = int_t0^tend g(t,y,p) dt,
  * where
  *   g(t,y,p) = 0.5*J1*v1^2 + 0.5*J2*v3^2 + 0.5*m2*v2^2
- *              
- * -----------------------------------------------------------------
- */
+ *
+ * -----------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
 
-#include <idas/idas.h>
-#include <idas/idas_dense.h>
-#include <nvector/nvector_serial.h>
-#include <sundials/sundials_math.h>
-
+#include <idas/idas.h>                 /* prototypes for IDA fcts., consts.    */
+#include <nvector/nvector_serial.h>    /* access to serial N_Vector            */
+#include <sunmatrix/sunmatrix_dense.h> /* access to dense SUNMatrix            */
+#include <sunlinsol/sunlinsol_dense.h> /* access to dense SUNLinearSolver      */
+#include <sundials/sundials_types.h>   /* defs. of realtype, sunindextype      */
 
 #define Ith(v,i)    NV_Ith_S(v,i-1)       /* i-th vector component i= 1..NEQ */
 
@@ -69,20 +74,20 @@ typedef struct {
   realtype F;
 } *UserData;
 
-static int ressc(realtype tres, N_Vector yy, N_Vector yp, 
+static int ressc(realtype tres, N_Vector yy, N_Vector yp,
            N_Vector resval, void *user_data);
 static int rhsQ(realtype t, N_Vector yy, N_Vector yp, N_Vector qdot, void *user_data);
 
-static int rhsQS(int Ns, realtype t, N_Vector yy, N_Vector yp, 
-                 N_Vector *yyS, N_Vector *ypS, N_Vector rrQ, N_Vector *rhsQS,
+static int rhsQS(int Ns, realtype t, N_Vector yy, N_Vector yp,
+                 N_Vector *yyS, N_Vector *ypS, N_Vector rrQ, N_Vector *rhsvalQS,
                  void *user_data,  N_Vector yytmp, N_Vector yptmp, N_Vector tmpQS);
 
 
 static void setIC(N_Vector yy, N_Vector yp, UserData data);
 static void force(N_Vector yy, realtype *Q, UserData data);
 
-static void PrintFinalStats(void *mem);
-static int check_flag(void *flagvalue, char *funcname, int opt);
+static int PrintFinalStats(void *mem);
+static int check_retval(void *returnvalue, const char *funcname, int opt);
 /*
  *--------------------------------------------------------------------
  * Main Program
@@ -98,17 +103,27 @@ int main(void)
   realtype tret;
   realtype pbar[2];
   realtype dp, G, Gm[2], Gp[2];
-  int flag, is;
+  int retval, is;
   realtype atolS[NP];
+  SUNMatrix A;
+  SUNLinearSolver LS;
+  SUNContext ctx;
 
-  id = N_VNew_Serial(NEQ);
-  yy = N_VNew_Serial(NEQ);
-  yp = N_VNew_Serial(NEQ);
-  q = N_VNew_Serial(1);
+  A  = NULL;
+  LS = NULL;
+
+  /* Create the SUNDIALS context object for this simulation */
+  retval = SUNContext_Create(NULL, &ctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) return 1;
+
+  id = N_VNew_Serial(NEQ, ctx);
+  yy = N_VClone(id);
+  yp = N_VClone(id);
+  q = N_VNew_Serial(1, ctx);
 
   yyS= N_VCloneVectorArray(NP,yy);
   ypS= N_VCloneVectorArray(NP,yp);
-  qS = N_VCloneVectorArray_Serial(NP, q);
+  qS = N_VCloneVectorArray(NP, q);
 
   data = (UserData) malloc(sizeof *data);
 
@@ -127,7 +142,7 @@ int main(void)
   NV_Ith_S(id, 8) = ZERO;
   NV_Ith_S(id, 7) = ZERO;
   NV_Ith_S(id, 6) = ZERO;
-  
+
   printf("\nSlider-Crank example for IDAS:\n");
 
   /* Consistent IC*/
@@ -139,57 +154,76 @@ int main(void)
   }
 
   /* IDA initialization */
-  mem = IDACreate();
-  flag = IDAInit(mem, ressc, TBEGIN, yy, yp);
-  flag = IDASStolerances(mem, RTOLF, ATOLF);
-  flag = IDASetUserData(mem, data);
-  flag = IDASetId(mem, id);
-  flag = IDASetSuppressAlg(mem, TRUE);
-  flag = IDASetMaxNumSteps(mem, 20000);
+  mem = IDACreate(ctx);
+  retval = IDAInit(mem, ressc, TBEGIN, yy, yp);
+  retval = IDASStolerances(mem, RTOLF, ATOLF);
+  retval = IDASetUserData(mem, data);
+  retval = IDASetId(mem, id);
+  retval = IDASetSuppressAlg(mem, SUNTRUE);
+  retval = IDASetMaxNumSteps(mem, 20000);
 
-  /* Call IDADense and set up the linear solver. */
-  flag = IDADense(mem, NEQ);
+  /* Create dense SUNMatrix for use in linear solves */
+  A = SUNDenseMatrix(NEQ, NEQ, ctx);
+  if(check_retval((void *)A, "SUNDenseMatrix", 0)) return(1);
 
-  flag = IDASensInit(mem, NP, IDA_SIMULTANEOUS, NULL, yyS, ypS);
+  /* Create dense SUNLinearSolver object */
+  LS = SUNLinSol_Dense(yy, A, ctx);
+  if(check_retval((void *)LS, "SUNLinSol_Dense", 0)) return(1);
+
+  /* Attach the matrix and linear solver */
+  retval = IDASetLinearSolver(mem, LS, A);
+  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
+
+  retval = IDASensInit(mem, NP, IDA_SIMULTANEOUS, NULL, yyS, ypS);
   pbar[0] = data->params[0];pbar[1] = data->params[1];
-  flag = IDASetSensParams(mem, data->params, pbar, NULL);
-  flag = IDASensEEtolerances(mem);
-  IDASetSensErrCon(mem, TRUE);
-  
+  retval = IDASetSensParams(mem, data->params, pbar, NULL);
+  retval = IDASensEEtolerances(mem);
+  IDASetSensErrCon(mem, SUNTRUE);
+
   N_VConst(ZERO, q);
-  flag = IDAQuadInit(mem, rhsQ, q);
-  flag = IDAQuadSStolerances(mem, RTOLQ, ATOLQ);
-  flag = IDASetQuadErrCon(mem, TRUE);
-  
-  N_VConst(ZERO, qS[0]);
-  flag = IDAQuadSensInit(mem, rhsQS, qS);
+  retval = IDAQuadInit(mem, rhsQ, q);
+  retval = IDAQuadSStolerances(mem, RTOLQ, ATOLQ);
+  retval = IDASetQuadErrCon(mem, SUNTRUE);
+
+  for (is=0; is<NP; is++) N_VConst(ZERO, qS[is]);
+  retval = IDAQuadSensInit(mem, rhsQS, qS);
   atolS[0] = atolS[1] = ATOLQ;
-  flag = IDAQuadSensSStolerances(mem, RTOLQ, atolS);
-  flag = IDASetQuadSensErrCon(mem, TRUE);  
-  
+  retval = IDAQuadSensSStolerances(mem, RTOLQ, atolS);
+  retval = IDASetQuadSensErrCon(mem, SUNTRUE);
+
 
   /* Perform forward run */
   printf("\nForward integration ... ");
 
-  flag = IDASolve(mem, TEND, &tret, yy, yp, IDA_NORMAL);
-  if (check_flag(&flag, "IDASolve", 1)) return(1);
+  retval = IDASolve(mem, TEND, &tret, yy, yp, IDA_NORMAL);
+  if (check_retval(&retval, "IDASolve", 1)) return(1);
 
   printf("done!\n");
 
-  PrintFinalStats(mem);
+  retval = PrintFinalStats(mem);
+  if (check_retval(&retval, "PrintFinalStats", 1)) return(1);
 
   IDAGetQuad(mem, &tret, q);
   printf("--------------------------------------------\n");
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("  G = %24.16Lf\n", Ith(q,1));
+#else
   printf("  G = %24.16f\n", Ith(q,1));
+#endif
   printf("--------------------------------------------\n\n");
-  
+
   IDAGetQuadSens(mem, &tret, qS);
   printf("-------------F O R W A R D------------------\n");
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("   dG/dp:  %12.4Le %12.4Le\n", Ith(qS[0],1), Ith(qS[1],1));
+#else
   printf("   dG/dp:  %12.4e %12.4e\n", Ith(qS[0],1), Ith(qS[1],1));
+#endif
   printf("--------------------------------------------\n\n");
 
   IDAFree(&mem);
-
+  SUNLinSolFree(LS);
+  SUNMatDestroy(A);
 
 
   /* Finite differences for dG/dp */
@@ -197,21 +231,31 @@ int main(void)
   data->params[0] = ONE;
   data->params[1] = ONE;
 
-  mem = IDACreate();
+  mem = IDACreate(ctx);
 
   setIC(yy, yp, data);
-  flag = IDAInit(mem, ressc, TBEGIN, yy, yp);
-  flag = IDASStolerances(mem, RTOLFD, ATOLFD);
-  flag = IDASetUserData(mem, data);
-  flag = IDASetId(mem, id);
-  flag = IDASetSuppressAlg(mem, TRUE);
-  /* Call IDADense and set up the linear solver. */
-  flag = IDADense(mem, NEQ);
+  retval = IDAInit(mem, ressc, TBEGIN, yy, yp);
+  retval = IDASStolerances(mem, RTOLFD, ATOLFD);
+  retval = IDASetUserData(mem, data);
+  retval = IDASetId(mem, id);
+  retval = IDASetSuppressAlg(mem, SUNTRUE);
+
+  /* Create dense SUNMatrix for use in linear solves */
+  A = SUNDenseMatrix(NEQ, NEQ, ctx);
+  if(check_retval((void *)A, "SUNDenseMatrix", 0)) return(1);
+
+  /* Create dense SUNLinearSolver object */
+  LS = SUNLinSol_Dense(yy, A, ctx);
+  if(check_retval((void *)LS, "SUNLinSol_Dense", 0)) return(1);
+
+  /* Attach the matrix and linear solver */
+  retval = IDASetLinearSolver(mem, LS, A);
+  if(check_retval(&retval, "IDASetLinearSolver", 1)) return(1);
 
   N_VConst(ZERO, q);
   IDAQuadInit(mem, rhsQ, q);
   IDAQuadSStolerances(mem, RTOLQ, ATOLQ);
-  IDASetQuadErrCon(mem, TRUE);
+  IDASetQuadErrCon(mem, SUNTRUE);
 
   IDASolve(mem, TEND, &tret, yy, yp, IDA_NORMAL);
 
@@ -277,19 +321,33 @@ int main(void)
   Gp[1] = Ith(q,1);
 
   IDAFree(&mem);
+  SUNLinSolFree(LS);
+  SUNMatDestroy(A);
 
   printf("\n\n   Checking using Finite Differences \n\n");
 
   printf("---------------BACKWARD------------------\n");
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("   dG/dp:  %12.4Le %12.4Le\n", (G-Gm[0])/dp, (G-Gm[1])/dp);
+#else
   printf("   dG/dp:  %12.4e %12.4e\n", (G-Gm[0])/dp, (G-Gm[1])/dp);
+#endif
   printf("-----------------------------------------\n\n");
 
   printf("---------------FORWARD-------------------\n");
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("   dG/dp:  %12.4Le %12.4Le\n", (Gp[0]-G)/dp, (Gp[1]-G)/dp);
+#else
   printf("   dG/dp:  %12.4e %12.4e\n", (Gp[0]-G)/dp, (Gp[1]-G)/dp);
+#endif
   printf("-----------------------------------------\n\n");
 
   printf("--------------CENTERED-------------------\n");
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("   dG/dp:  %12.4Le %12.4Le\n", (Gp[0]-Gm[0])/(TWO*dp) ,(Gp[1]-Gm[1])/(TWO*dp));
+#else
   printf("   dG/dp:  %12.4e %12.4e\n", (Gp[0]-Gm[0])/(TWO*dp) ,(Gp[1]-Gm[1])/(TWO*dp));
+#endif
   printf("-----------------------------------------\n\n");
 
 
@@ -297,11 +355,17 @@ int main(void)
   free(data);
 
   N_VDestroy(id);
-  N_VDestroy_Serial(yy);
-  N_VDestroy_Serial(yp);
-  N_VDestroy_Serial(q);
+  N_VDestroy(yy);
+  N_VDestroy(yp);
+  N_VDestroy(q);
+
+  N_VDestroyVectorArray(yyS, NP);
+  N_VDestroyVectorArray(ypS, NP);
+  N_VDestroyVectorArray(qS,  NP);
+
+  SUNContext_Free(&ctx);
+
   return(0);
-  
 }
 
 static void setIC(N_Vector yy, N_Vector yp, UserData data)
@@ -320,7 +384,7 @@ static void setIC(N_Vector yy, N_Vector yp, UserData data)
   J1 = data->J1;
   m2 = data->m2;
   J2 = data->J2;
-  
+
   q = pi/TWO;
   p = asin(-a);
   x = cos(p);
@@ -328,7 +392,7 @@ static void setIC(N_Vector yy, N_Vector yp, UserData data)
   NV_Ith_S(yy,0) = q;
   NV_Ith_S(yy,1) = x;
   NV_Ith_S(yy,2) = p;
-  
+
   force(yy, Q, data);
 
   NV_Ith_S(yp,3) = Q[0]/J1;
@@ -341,7 +405,7 @@ static void force(N_Vector yy, realtype *Q, UserData data)
 {
   realtype a, k, c, l0, F;
   realtype q, x, p;
-  realtype qd, xd, pd;  
+  realtype qd, xd, pd;
   realtype s1, c1, s2, c2, s21, c21;
   realtype l2, l, ld;
   realtype f, fl;
@@ -368,7 +432,7 @@ static void force(N_Vector yy, realtype *Q, UserData data)
   c21 = c2*c1 + s2*s1;
 
   l2 = x*x - x*(c2+a*c1) + (ONE + a*a)/FOUR + a*c21/TWO;
-  l = SUNRsqrt(l2);
+  l = sqrt(l2);
   ld = TWO*x*xd - xd*(c2+a*c1) + x*(s2*pd+a*s1*qd) - a*s21*(pd-qd)/TWO;
   ld /= TWO*l;
 
@@ -388,7 +452,7 @@ static int ressc(realtype tres, N_Vector yy, N_Vector yp, N_Vector rr, void *use
   realtype a, J1, m2, J2;
   realtype *yval, *ypval, *rval;
   realtype q, x, p;
-  realtype qd, xd, pd;  
+  realtype qd, xd, pd;
   realtype lam1, lam2, mu1, mu2;
   realtype s1, c1, s2, c2;
 
@@ -399,9 +463,9 @@ static int ressc(realtype tres, N_Vector yy, N_Vector yp, N_Vector rr, void *use
   m2 = data->m2;
   J2 = data->J2;
 
-  yval = NV_DATA_S(yy); 
-  ypval = NV_DATA_S(yp); 
-  rval = NV_DATA_S(rr);
+  yval = N_VGetArrayPointer(yy);
+  ypval = N_VGetArrayPointer(yp);
+  rval = N_VGetArrayPointer(rr);
 
   q = yval[0];
   x = yval[1];
@@ -426,11 +490,11 @@ static int ressc(realtype tres, N_Vector yy, N_Vector yp, N_Vector rr, void *use
 
   rval[0] = ypval[0] - qd + a*s1*mu1 - a*c1*mu2;
   rval[1] = ypval[1] - xd + mu1;
-  rval[2] = ypval[2] - pd + s2*mu1 - c2*mu2; 
+  rval[2] = ypval[2] - pd + s2*mu1 - c2*mu2;
 
   rval[3] = J1*ypval[3] - Q[0] + a*s1*lam1 - a*c1*lam2;
   rval[4] = m2*ypval[4] - Q[1] + lam1;
-  rval[5] = J2*ypval[5] - Q[2] + s2*lam1 - c2*lam2; 
+  rval[5] = J2*ypval[5] - Q[2] + s2*lam1 - c2*lam2;
 
   rval[6] = x - c2 - a*c1;
   rval[7] = -s2 - a*s1;
@@ -444,15 +508,13 @@ static int ressc(realtype tres, N_Vector yy, N_Vector yp, N_Vector rr, void *use
 static int rhsQ(realtype t, N_Vector yy, N_Vector yp, N_Vector qdot, void *user_data)
 {
   realtype v1, v2, v3;
-  realtype m1, J1, m2, J2, a;
+  realtype J1, m2, J2;
   UserData data;
-  
+
   data = (UserData) user_data;
   J1 = data->J1;
-  m1 = data->m1;
   m2 = data->m2;
   J2 = data->J2;
-  a  = data->a;
 
   v1 = Ith(yy,4);
   v2 = Ith(yy,5);
@@ -463,54 +525,54 @@ static int rhsQ(realtype t, N_Vector yy, N_Vector yp, N_Vector qdot, void *user_
   return(0);
 }
 
-static int rhsQS(int Ns, realtype t, N_Vector yy, N_Vector yp, 
-                 N_Vector *yyS, N_Vector *ypS, N_Vector rrQ, N_Vector *rhsQS,
+static int rhsQS(int Ns, realtype t, N_Vector yy, N_Vector yp,
+                 N_Vector *yyS, N_Vector *ypS, N_Vector rrQ, N_Vector *rhsvalQS,
                  void *user_data,  N_Vector yytmp, N_Vector yptmp, N_Vector tmpQS)
 {
   realtype v1, v2, v3;
-  realtype m1, J1, m2, J2, a;
+  realtype J1, m2, J2;
   UserData data;
   realtype s1, s2, s3;
-  
+
   data = (UserData) user_data;
+
   J1 = data->J1;
-  m1 = data->m1;
   m2 = data->m2;
   J2 = data->J2;
-  a  = data->a;
 
   v1 = Ith(yy,4);
   v2 = Ith(yy,5);
   v3 = Ith(yy,6);
-  
+
   /* Sensitivities of v. */
   s1 = Ith(yyS[0],4);
   s2 = Ith(yyS[0],5);
   s3 = Ith(yyS[0],6);
 
-  Ith(rhsQS[0], 1) = J1*v1*s1 + m2*v2*s2 + J2*v3*s3;
+  Ith(rhsvalQS[0], 1) = J1*v1*s1 + m2*v2*s2 + J2*v3*s3;
 
   s1 = Ith(yyS[1],4);
   s2 = Ith(yyS[1],5);
   s3 = Ith(yyS[1],6);
 
-  Ith(rhsQS[1], 1) = J1*v1*s1 + m2*v2*s2 + J2*v3*s3;
+  Ith(rhsvalQS[1], 1) = J1*v1*s1 + m2*v2*s2 + J2*v3*s3;
 
   return(0);
 }
 
-static void PrintFinalStats(void *mem)
+static int PrintFinalStats(void *mem)
 {
-  int flag;
-  long int nst, nni, nje, nre, nreLS, netf, ncfn;
+  int retval;
+  long int nst, nni, nnf, nje, nre, nreLS, netf, ncfn;
 
-  flag = IDAGetNumSteps(mem, &nst);
-  flag = IDAGetNumResEvals(mem, &nre);
-  flag = IDADlsGetNumJacEvals(mem, &nje);
-  flag = IDAGetNumNonlinSolvIters(mem, &nni);
-  flag = IDAGetNumErrTestFails(mem, &netf);
-  flag = IDAGetNumNonlinSolvConvFails(mem, &ncfn);
-  flag = IDADlsGetNumResEvals(mem, &nreLS);
+  retval = IDAGetNumSteps(mem, &nst);
+  retval = IDAGetNumResEvals(mem, &nre);
+  retval = IDAGetNumJacEvals(mem, &nje);
+  retval = IDAGetNumNonlinSolvIters(mem, &nni);
+  retval = IDAGetNumErrTestFails(mem, &netf);
+  retval = IDAGetNumNonlinSolvConvFails(mem, &nnf);
+  retval = IDAGetNumStepSolveFails(mem, &ncfn);
+  retval = IDAGetNumLinResEvals(mem, &nreLS);
 
   printf("\nFinal Run Statistics: \n\n");
   printf("Number of steps                    = %ld\n", nst);
@@ -518,32 +580,35 @@ static void PrintFinalStats(void *mem)
   printf("Number of Jacobian evaluations     = %ld\n", nje);
   printf("Number of nonlinear iterations     = %ld\n", nni);
   printf("Number of error test failures      = %ld\n", netf);
-  printf("Number of nonlinear conv. failures = %ld\n", ncfn);
+  printf("Number of nonlinear conv. failures = %ld\n", nnf);
+  printf("Number of step solver failures     = %ld\n", ncfn);
+
+  return(retval);
 }
 
 
-static int check_flag(void *flagvalue, char *funcname, int opt)
+static int check_retval(void *returnvalue, const char *funcname, int opt)
 {
-  int *errflag;
+  int *retval;
 
   /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-  if (opt == 0 && flagvalue == NULL) {
+  if (opt == 0 && returnvalue == NULL) {
     fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
-	    funcname);
+            funcname);
     return(1); }
 
-  /* Check if flag < 0 */
+  /* Check if retval < 0 */
   else if (opt == 1) {
-    errflag = (int *) flagvalue;
-    if (*errflag < 0) {
-      fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with flag = %d\n\n",
-	      funcname, *errflag);
+    retval = (int *) returnvalue;
+    if (*retval < 0) {
+      fprintf(stderr, "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
+              funcname, *retval);
       return(1); }}
 
   /* Check if function returned NULL pointer - no memory allocated */
-  else if (opt == 2 && flagvalue == NULL) {
+  else if (opt == 2 && returnvalue == NULL) {
     fprintf(stderr, "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
-	    funcname);
+            funcname);
     return(1); }
 
   return(0);
