@@ -358,6 +358,8 @@ SUNDIALS_EXPORT int ARKStepGetRootInfo(void *arkode_mem,
                                        int *rootsfound);
 SUNDIALS_EXPORT int ARKStepGetNumConstrFails(void *arkode_mem,
                                              long int *nconstrfails);
+SUNDIALS_EXPORT int ARKStepGetUserData(void *arkode_mem,
+                                       void **user_data);
 SUNDIALS_EXPORT int ARKStepPrintAllStats(void *arkode_mem, FILE *outfile,
                                          SUNOutputFormat fmt);
 SUNDIALS_EXPORT char *ARKStepGetReturnFlagName(long int flag);
