@@ -47,7 +47,7 @@ int ARKStepSetNonlinearSolver(void *arkode_mem, SUNNonlinearSolver NLS)
 
   /* Return immediately if NLS input is NULL */
   if (NLS == NULL) {
-    arkProcessError(NULL, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(NULL, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetNonlinearSolver",
                     "The NLS input must be non-NULL");
     return(ARK_ILL_INPUT);
@@ -57,7 +57,7 @@ int ARKStepSetNonlinearSolver(void *arkode_mem, SUNNonlinearSolver NLS)
   if ( (NLS->ops->gettype    == NULL) ||
        (NLS->ops->solve      == NULL) ||
        (NLS->ops->setsysfn   == NULL) ) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "ARKStepSetNonlinearSolver",
                     "NLS does not support required operations");
     return(ARK_ILL_INPUT);
@@ -75,7 +75,7 @@ int ARKStepSetNonlinearSolver(void *arkode_mem, SUNNonlinearSolver NLS)
   retval = SUNNonlinSolSetConvTestFn(step_mem->NLS, arkStep_NlsConvTest,
                                      (void*) ark_mem);
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetNonlinearSolver",
                     "Setting convergence test function failed");
     return(ARK_ILL_INPUT);
@@ -84,7 +84,7 @@ int ARKStepSetNonlinearSolver(void *arkode_mem, SUNNonlinearSolver NLS)
   /* set default nonlinear iterations */
   retval = SUNNonlinSolSetMaxIters(step_mem->NLS, step_mem->maxcor);
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetNonlinearSolver",
                     "Setting maximum number of nonlinear iterations failed");
     return(ARK_ILL_INPUT);
@@ -92,7 +92,7 @@ int ARKStepSetNonlinearSolver(void *arkode_mem, SUNNonlinearSolver NLS)
 
   /* set the nonlinear system RHS function */
   if (!(step_mem->fi)) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "ARKStepSetNonlinearSolver",
                     "The implicit ODE RHS function is NULL");
     return(ARK_ILL_INPUT);
@@ -182,7 +182,7 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
 
   /* access ARKodeARKStepMem structure */
   if (ark_mem->step_mem==NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE::ARKStep",
                     "arkStep_NlsInit", MSG_ARKSTEP_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -198,7 +198,7 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
   else
     retval = SUNNonlinSolSetLSetupFn(step_mem->NLS, NULL);
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "arkStep_NlsInit",
                     "Setting the linear solver setup function failed");
     return(ARK_NLS_INIT_FAIL);
@@ -210,7 +210,7 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
   else
     retval = SUNNonlinSolSetLSolveFn(step_mem->NLS, NULL);
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "arkStep_NlsInit",
                     "Setting linear solver solve function failed");
     return(ARK_NLS_INIT_FAIL);
@@ -225,7 +225,7 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
     } else if (step_mem->mass_type == MASS_TIMEDEP) {
       retval = SUNNonlinSolSetSysFn(step_mem->NLS, arkStep_NlsResidual_MassTDep);
     } else {
-      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                       "arkStep_NlsInit",
                       "Invalid mass matrix type");
       return(ARK_ILL_INPUT);
@@ -238,19 +238,19 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
     } else if (step_mem->mass_type == MASS_TIMEDEP) {
       retval = SUNNonlinSolSetSysFn(step_mem->NLS, arkStep_NlsFPFunction_MassTDep);
     } else {
-      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+      arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                       "arkStep_NlsInit",
                       "Invalid mass matrix type");
       return(ARK_ILL_INPUT);
     }
   } else {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "arkStep_NlsInit",
                     "Invalid nonlinear solver type");
     return(ARK_ILL_INPUT);
   }
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "arkStep_NlsInit",
                     "Setting nonlinear system function failed");
     return(ARK_ILL_INPUT);
@@ -259,7 +259,7 @@ int arkStep_NlsInit(ARKodeMem ark_mem)
   /* initialize nonlinear solver */
   retval = SUNNonlinSolInitialize(step_mem->NLS);
   if (retval != ARK_SUCCESS) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE::ARKStep",
                     "arkStep_NlsInit", MSG_NLS_INIT_FAIL);
     return(ARK_NLS_INIT_FAIL);
   }
@@ -292,7 +292,7 @@ int arkStep_Nls(ARKodeMem ark_mem, int nflag)
 
   /* access ARKodeARKStepMem structure */
   if (ark_mem->step_mem==NULL) {
-    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKode::ARKStep",
+    arkProcessError(ark_mem, ARK_MEM_NULL, "ARKODE::ARKStep",
                     "arkStep_Nls", MSG_ARKSTEP_NO_MEM);
     return(ARK_MEM_NULL);
   }
@@ -354,7 +354,7 @@ int arkStep_Nls(ARKodeMem ark_mem, int nflag)
     return(ARK_SUCCESS);
   }
 
-  /* check for recoverable failure, return ARKode::CONV_FAIL */
+  /* check for recoverable failure, return ARKODE::CONV_FAIL */
   if (retval == SUN_NLS_CONV_RECVR) return(CONV_FAIL);
 
   return(retval);
@@ -368,7 +368,7 @@ int arkStep_Nls(ARKodeMem ark_mem, int nflag)
 /*---------------------------------------------------------------
   arkStep_NlsLSetup:
 
-  This routine wraps the ARKode linear solver interface 'setup'
+  This routine wraps the ARKODE linear solver interface 'setup'
   routine for use by the nonlinear solver object.
   ---------------------------------------------------------------*/
 int arkStep_NlsLSetup(booleantype jbad, booleantype* jcur, void* arkode_mem)
@@ -385,7 +385,7 @@ int arkStep_NlsLSetup(booleantype jbad, booleantype* jcur, void* arkode_mem)
   /* update convfail based on jbad flag */
   if (jbad)  step_mem->convfail = ARK_FAIL_BAD_J;
 
-  /* Use ARKode's tempv1, tempv2 and tempv3 as
+  /* Use ARKODE's tempv1, tempv2 and tempv3 as
      temporary vectors for the linear solver setup routine */
   step_mem->nsetups++;
   retval = step_mem->lsetup(ark_mem, step_mem->convfail, ark_mem->tcur,
@@ -412,7 +412,7 @@ int arkStep_NlsLSetup(booleantype jbad, booleantype* jcur, void* arkode_mem)
 /*---------------------------------------------------------------
   arkStep_NlsLSolve:
 
-  This routine wraps the ARKode linear solver interface 'solve'
+  This routine wraps the ARKODE linear solver interface 'solve'
   routine for use by the nonlinear solver object.
   ---------------------------------------------------------------*/
 int arkStep_NlsLSolve(N_Vector b, void* arkode_mem)
