@@ -11,7 +11,7 @@
  * SPDX-License-Identifier: BSD-3-Clause
  * SUNDIALS Copyright End
  *---------------------------------------------------------------
- * Implementation header file for the main ARKode integrator.
+ * Implementation header file for the main ARKODE integrator.
  *--------------------------------------------------------------*/
 
 #ifndef _ARKODE_IMPL_H
@@ -47,10 +47,10 @@ extern "C" {
 #define ARK_LOGGER ark_mem->sunctx->logger
 
 /*===============================================================
-  ARKode Private Constants
+  ARKODE Private Constants
   ===============================================================*/
 
-/* Basic ARKode defaults */
+/* Basic ARKODE defaults */
 #define Q_DEFAULT        4      /* method order                       */
 #define MXSTEP_DEFAULT   500    /* max steps between returns          */
 #define MAXNEF           7      /* max number of error failures       */
@@ -75,7 +75,7 @@ extern "C" {
 
 
 /*===============================================================
-  ARKode Routine-Specific Constants
+  ARKODE Routine-Specific Constants
   ===============================================================*/
 
 /*---------------------------------------------------------------
@@ -127,7 +127,7 @@ extern "C" {
 
 
 /*===============================================================
-  ARKode Interface function definitions
+  ARKODE Interface function definitions
   ===============================================================*/
 
 /* NOTE: documentation for the purpose of these functions is
@@ -193,7 +193,7 @@ typedef int (*ARKTimestepStepFn)(void* arkode_mem, realtype *dsm,
 
 
 /*===============================================================
-  ARKode interpolation module definition
+  ARKODE interpolation module definition
   ===============================================================*/
 
 /* Forward reference for pointer to ARKInterp_Ops object */
@@ -239,7 +239,7 @@ int arkInterpEvaluate(void* arkode_mem, ARKInterp interp,
 
 
 /*===============================================================
-  ARKode data structures
+  ARKODE data structures
   ===============================================================*/
 
 /*---------------------------------------------------------------
@@ -348,7 +348,7 @@ typedef struct ARKodeMemRec {
   realtype eta;                /* eta = hprime / h                         */
   realtype tcur;               /* current internal value of t
                                   (changes with each stage)                */
-  realtype tretlast;           /* value of tret last returned by ARKode    */
+  realtype tretlast;           /* value of tret last returned by ARKODE    */
   booleantype fixedstep;       /* flag to disable temporal adaptivity      */
   ARKodeHAdaptMem hadapt_mem;  /* time step adaptivity structure           */
 
@@ -374,11 +374,11 @@ typedef struct ARKodeMemRec {
   booleantype report;   /* flag to enable/disable diagnostic output    */
   FILE       *diagfp;   /* diagnostic outputs are sent to diagfp   */
 
-  /* Space requirements for ARKode */
+  /* Space requirements for ARKODE */
   sunindextype lrw1;        /* no. of realtype words in 1 N_Vector          */
   sunindextype liw1;        /* no. of integer words in 1 N_Vector           */
-  long int lrw;             /* no. of realtype words in ARKode work vectors */
-  long int liw;             /* no. of integer words in ARKode work vectors  */
+  long int lrw;             /* no. of realtype words in ARKODE work vectors */
+  long int liw;             /* no. of integer words in ARKODE work vectors  */
 
   /* Saved Values */
   realtype    h0u;          /* actual initial stepsize                     */
@@ -397,7 +397,7 @@ typedef struct ARKodeMemRec {
   /* Error handler function and error ouput file */
   ARKErrHandlerFn ehfun;    /* error messages are handled by ehfun        */
   void           *eh_data;  /* data pointer passed to ehfun               */
-  FILE           *errfp;    /* ARKode error messages are sent to errfp    */
+  FILE           *errfp;    /* ARKODE error messages are sent to errfp    */
 
   /* Rootfinding Data */
   ARKodeRootMem root_mem;          /* root-finding structure */
@@ -429,7 +429,7 @@ typedef struct ARKodeMemRec {
   ===============================================================*/
 
 /*---------------------------------------------------------------
-  Communication between ARKode and a ARKode Linear Solver
+  Communication between ARKODE and a ARKODE Linear Solver
   -----------------------------------------------------------------
   convfail (input to lsetup)
 
@@ -467,9 +467,9 @@ typedef struct ARKodeMemRec {
   ARKLinsolInitFn
   ---------------------------------------------------------------
   This function should complete initializations for a specific
-  ARKode linear solver interface, such as counters and statistics.
+  ARKODE linear solver interface, such as counters and statistics.
   This should return 0 if it has successfully initialized the
-  ARKode linear solver interface and a negative value otherwise.
+  ARKODE linear solver interface and a negative value otherwise.
   If an error does occur, an appropriate message should be sent
   to the error handler function.
   ---------------------------------------------------------------*/
@@ -489,13 +489,13 @@ typedef struct ARKodeMemRec {
              the solution of the nonlinear equation on the
              current time step for which the linear solver is
              being used. This flag can be used to help decide
-             whether the Jacobian data kept by a ARKode linear
+             whether the Jacobian data kept by a ARKODE linear
              solver needs to be updated or not.
              Its possible values have been documented above.
 
-  tpred - the time for the current ARKode internal step.
+  tpred - the time for the current ARKODE internal step.
 
-  ypred - the predicted y vector for the current ARKode internal
+  ypred - the predicted y vector for the current ARKODE internal
           step.
 
   fpred - f(tpred, ypred).
@@ -505,7 +505,7 @@ typedef struct ARKodeMemRec {
             data is current after the call and should set
             *jcurPtr=SUNFALSE if its Jacobian data is not current.
             Note: If lsetup calls for re-evaluation of
-            Jacobian data (based on convfail and ARKode state
+            Jacobian data (based on convfail and ARKODE state
             data), it should return *jcurPtr=SUNTRUE always;
             otherwise an infinite loop can result.
 
@@ -534,7 +534,7 @@ typedef struct ARKodeMemRec {
   factor eplifac.  The input mnewt is the current nonlinear
   iteration index (ignored by ARKDLS, used by ARKSPILS).
 
-  Additional vectors that are set within the ARKode memory
+  Additional vectors that are set within the ARKODE memory
   structure, and that may be of use within an iterative linear
   solver, include:
 
@@ -607,7 +607,7 @@ typedef struct ARKodeMemRec {
   ignore this value and the ARKSPILS solver tightens it by the
   factor eplifac.  The solution is to be returned in the vector b.
 
-  Additional vectors that are set within the ARKode memory
+  Additional vectors that are set within the ARKODE memory
   structure, and that may be of use within an iterative linear
   solver, include:
 
@@ -641,13 +641,13 @@ typedef struct ARKodeMemRec {
   ---------------------------------------------------------------
   This routine should attach the various set of system linear
   solver interface routines, linear solver interface data
-  structure, and system linear solver type to the ARKode time
+  structure, and system linear solver type to the ARKODE time
   stepping module pointed to in ark_mem->step_mem.  This will
-  be called by the ARKode linear solver interface.
+  be called by the ARKODE linear solver interface.
 
   This routine should return 0 if it has successfully attached
   these items and a negative value otherwise.  If an error does
-  occur, an appropriate message should be sent to the ARKode
+  occur, an appropriate message should be sent to the ARKODE
   error handler function.
   ---------------------------------------------------------------*/
 
@@ -656,13 +656,13 @@ typedef struct ARKodeMemRec {
   ---------------------------------------------------------------
   This routine should attach the various set of mass matrix
   linear solver interface routines, data structure, mass matrix
-  type, and solver type to the ARKode time stepping module
+  type, and solver type to the ARKODE time stepping module
   pointed to in ark_mem->step_mem.  This will be called by the
-  ARKode linear solver interface.
+  ARKODE linear solver interface.
 
   This routine should return 0 if it has successfully attached
   these items, and a negative value otherwise.  If an error does
-  occur, an appropriate message should be sent to the ARKode
+  occur, an appropriate message should be sent to the ARKODE
   error handler function.
   ---------------------------------------------------------------*/
 
@@ -670,7 +670,7 @@ typedef struct ARKodeMemRec {
   ARKTimestepDisableLSetup
   ---------------------------------------------------------------
   This routine should NULLify any ARKLinsolSetupFn function
-  pointer stored in the ARKode time stepping module (initially set
+  pointer stored in the ARKODE time stepping module (initially set
   in a call to ARKTimestepAttachLinsolFn).
 
   This routine has no return value.
@@ -680,7 +680,7 @@ typedef struct ARKodeMemRec {
   ARKTimestepDisableMSetup
   ---------------------------------------------------------------
   This routine should NULLify any ARKMassSetupFn function pointer
-  stored in the ARKode time stepping module (initially set in a
+  stored in the ARKODE time stepping module (initially set in a
   call to ARKTimestepAttachMasssolFn).
 
   This routine has no return value.
@@ -690,8 +690,8 @@ typedef struct ARKodeMemRec {
   ARKTimestepGetLinMemFn
   ---------------------------------------------------------------
   This routine should return the linear solver memory structure
-  used by the ARKode time stepping module pointed to in
-  ark_mem->step_mem.  This will be called by the ARKode linear
+  used by the ARKODE time stepping module pointed to in
+  ark_mem->step_mem.  This will be called by the ARKODE linear
   solver interface.
 
   This routine should return NULL if no linear solver memory
@@ -702,8 +702,8 @@ typedef struct ARKodeMemRec {
   ARKTimestepGetMassMemFn
   ---------------------------------------------------------------
   This routine should return the mass matrix linear solver memory
-  structure used by the ARKode time stepping module pointed to in
-  ark_mem->step_mem.  This will be called the ARKode mass matrix
+  structure used by the ARKODE time stepping module pointed to in
+  ark_mem->step_mem.  This will be called the ARKODE mass matrix
   solver interface.
 
   This routine should return NULL if no mass matrix solver memory
@@ -751,7 +751,7 @@ typedef struct ARKodeMemRec {
 
   This routine should return 0 if it has successfully attached
   these items, and a negative value otherwise.  If an error does
-  occur, an appropriate message should be sent to the ARKode
+  occur, an appropriate message should be sent to the ARKODE
   error handler function.
   ---------------------------------------------------------------*/
 
@@ -761,13 +761,13 @@ typedef struct ARKodeMemRec {
   This routine is called just prior to performing internal time
   steps (after all user "set" routines have been called) from
   within arkInitialSetup. It should complete initializations for
-  a specific ARKode time stepping module, such as verifying
+  a specific ARKODE time stepping module, such as verifying
   compatibility of user-specified linear and nonlinear solver
   objects. The input init_type flag indicates if the call is
   for (re-)initializing, resizing, or resetting the problem.
 
   This routine should return 0 if it has successfully initialized
-  the ARKode time stepper module and a negative value otherwise.
+  the ARKODE time stepper module and a negative value otherwise.
   If an error does occur, an appropriate message should be sent
   to the error handler function.
   ---------------------------------------------------------------*/
@@ -796,7 +796,7 @@ typedef struct ARKodeMemRec {
 /*---------------------------------------------------------------
   ARKTimestepStepFn
   ---------------------------------------------------------------
-  This routine serves the primary purpose of any ARKode
+  This routine serves the primary purpose of any ARKODE
   time-stepping module: it performs a single time step of the
   method (with embedding, if possible).
 
@@ -842,7 +842,7 @@ typedef struct ARKodeMemRec {
 
 
 /*===============================================================
-  ARKode PROTOTYPE FUNCTIONS (MAY BE REPLACED BY USER)
+  ARKODE PROTOTYPE FUNCTIONS (MAY BE REPLACED BY USER)
   ===============================================================*/
 
 /* Prototype of internal rwtSet function */
@@ -856,7 +856,7 @@ void arkErrHandler(int error_code, const char *module,
 int arkExpStab(N_Vector y, realtype t, realtype *hstab, void *user_data);
 
 /*===============================================================
-  HIGH LEVEL ERROR HANDLER, USED THROUGHOUT ARKode
+  HIGH LEVEL ERROR HANDLER, USED THROUGHOUT ARKODE
   ===============================================================*/
 
 void arkProcessError(ARKodeMem ark_mem, int error_code,
@@ -864,7 +864,7 @@ void arkProcessError(ARKodeMem ark_mem, int error_code,
                      const char *msgfmt, ...);
 
 /*===============================================================
-  ARKode PRIVATE FUNCTION PROTOTYPES
+  ARKODE PRIVATE FUNCTION PROTOTYPES
   ===============================================================*/
 #ifdef __GNUC__
 #define SUNDIALS_UNUSED __attribute__ ((unused))
@@ -1019,6 +1019,7 @@ int arkGetNumStepSolveFails(void *arkode_mem, long int *nncfails);
 int arkGetStepStats(void *arkode_mem, long int *nsteps,
                     realtype *hinused, realtype *hlast,
                     realtype *hcur, realtype *tcur);
+int arkGetUserData(void *arkode_mem, void** user_data);
 int arkPrintAllStats(void *arkode_mem, FILE *outfile,
                      SUNOutputFormat fmt);
 char *arkGetReturnFlagName(long int flag);
@@ -1030,7 +1031,7 @@ int arkGetLastKFlag(void *arkode_mem, int *last_kflag);
 
 
 /*===============================================================
-  Reusable ARKode Error Messages
+  Reusable ARKODE Error Messages
   ===============================================================*/
 
 #if defined(SUNDIALS_EXTENDED_PRECISION)
@@ -1077,10 +1078,10 @@ int arkGetLastKFlag(void *arkode_mem, int *last_kflag);
 #define MSG_ARK_BAD_NVECTOR    "A required vector operation is not implemented."
 #define MSG_ARK_BAD_CONSTR     "Illegal values in constraints vector."
 #define MSG_ARK_NULL_DKY       "dky = NULL illegal."
-#define MSG_ARK_BAD_T          "Illegal value for t." MSG_TIME_INT
+#define MSG_ARK_BAD_T          "Illegal value for t. " MSG_TIME_INT
 #define MSG_ARK_NO_ROOT        "Rootfinding was not initialized."
 
-/* ARKode Error Messages */
+/* ARKODE Error Messages */
 #define MSG_ARK_YOUT_NULL      "yout = NULL illegal."
 #define MSG_ARK_TRET_NULL      "tret = NULL illegal."
 #define MSG_ARK_BAD_EWT        "Initial ewt has component(s) equal to zero (illegal)."
