@@ -11,7 +11,7 @@
  * SPDX-License-Identifier: BSD-3-Clause
  * SUNDIALS Copyright End
  *---------------------------------------------------------------
- * This is the implementation file for ARKode's temporal
+ * This is the implementation file for ARKODE's temporal
  * interpolation utility.
  *--------------------------------------------------------------*/
 
@@ -339,7 +339,7 @@ int arkInterpSetDegree_Hermite(void* arkode_mem, ARKInterp interp,
   /* on positive degree, check for allowable value and overwrite stored degree */
   if (degree >= 0) {
     if (degree > ARK_INTERP_MAX_DEGREE) {
-      arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKode",
+      arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKODE",
                       "arkInterpSetDegree_Hermite",
                       "Illegal degree specified.");
       return(ARK_ILL_INPUT);
@@ -506,7 +506,7 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
 
   /* error on illegal d */
   if (d < 0) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkInterpEvaluate_Hermite",
                     "Requested illegal derivative.");
     return (ARK_ILL_INPUT);
@@ -720,7 +720,7 @@ int arkInterpEvaluate_Hermite(void* arkode_mem, ARKInterp interp,
     break;
 
   default:
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkInterpEvaluate_Hermite",
                     "Illegal polynomial order");
     return (ARK_ILL_INPUT);
@@ -968,7 +968,7 @@ int arkInterpSetDegree_Lagrange(void* arkode_mem, ARKInterp I,
   /* on positive degree, check for allowable value and overwrite stored degree */
   if (degree >= 0) {
     if (degree > ARK_INTERP_MAX_DEGREE) {
-      arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKode",
+      arkProcessError(ark_mem, ARK_INTERP_FAIL, "ARKODE",
                       "arkInterpSetDegree_Lagrange",
                       "Illegal degree specified.");
       return(ARK_ILL_INPUT);
@@ -993,7 +993,7 @@ int arkInterpSetDegree_Lagrange(void* arkode_mem, ARKInterp I,
   This routine performs the following steps:
   1. allocates any missing/needed (t,y) history arrays
   2. zeros out stored (t,y) history
-  3. copies current (t,y) from main ARKode memory into history
+  3. copies current (t,y) from main ARKODE memory into history
   4. updates the 'active' history counter to 1
   ---------------------------------------------------------------*/
 int arkInterpInit_Lagrange(void* arkode_mem, ARKInterp I,
@@ -1178,7 +1178,7 @@ int arkInterpEvaluate_Lagrange(void* arkode_mem, ARKInterp I,
 
   /* error on illegal deriv */
   if ((deriv < 0) || (deriv > 3)) {
-    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKode",
+    arkProcessError(ark_mem, ARK_ILL_INPUT, "ARKODE",
                     "arkInterpEvaluate_Lagrange",
                     "Requested illegal derivative.");
     return (ARK_ILL_INPUT);
